@@ -29,7 +29,6 @@
 #include <QScopedPointer>
 #include <QPainter>
 #include <QVariant>
-#include <QLoggingCategory>
 
 //TODO: automatically schedule pre-rendering of animation frames
 //TODO: multithreaded SVG loading?
@@ -39,7 +38,7 @@ static const QString cacheName(QByteArray theme)
 	const QString appName = QCoreApplication::instance()->applicationName();
 	//e.g. "themes/foobar.desktop" -> "themes/foobar"
 	if (theme.endsWith(QByteArray(".desktop")))
-		theme.truncate(theme.length() - 8); //8 = strlen(".desktop")
+		theme.chop(8); //8 = strlen(".desktop")
 	return QStringLiteral("kgamerenderer-%1-%2")
 		.arg(appName).arg(QString::fromUtf8(theme));
 }
@@ -159,8 +158,6 @@ void KGameRenderer::setStrategyEnabled(KGameRenderer::Strategy strategy, bool en
 
 void KGameRendererPrivate::_k_setTheme(const KgTheme* theme)
 {
-	QLoggingCategory::setFilterRules(QStringLiteral("games.lib.debug = true"));
-
 	const KgTheme* oldTheme = m_currentTheme;
 	if (oldTheme == theme)
 	{
@@ -189,8 +186,6 @@ void KGameRendererPrivate::_k_setTheme(const KgTheme* theme)
 
 bool KGameRendererPrivate::setTheme(const KgTheme* theme)
 {
-	QLoggingCategory::setFilterRules(QStringLiteral("games.lib.debug = true"));
-
 	if (!theme)
 	{
 		return false;
@@ -204,8 +199,8 @@ bool KGameRendererPrivate::setTheme(const KgTheme* theme)
 		m_imageCache->setPixmapCaching(false); //see big comment in KGRPrivate class declaration
 		//check timestamp of cache vs. last write access to theme/SVG
 		const uint svgTimestamp = qMax(
-			QFileInfo(theme->graphicsPath()).lastModified().toTime_t(),
-			theme->property("_k_themeDescTimestamp").value<uint>()
+			QFileInfo(theme->graphicsPath()).lastModified().toSecsSinceEpoch(),
+                        theme->property("_k_themeDescTimestamp").value<qint64>()
 		);
 		QByteArray buffer;
 		if (!m_imageCache->find(QStringLiteral("kgr_timestamp"), &buffer))
